v1.1.1
======

Refresh project packaging.

v1.1.0
======

Added more API endpoints.

``api_cred`` parameter now will accept lists in addition to tuples.

v1.0.0
======

Initial release with four working API methods.
